@@ -265,17 +265,17 @@ def _download_images(config, images_url):
                 config.dirs["images"],
             ]
         )
-    subprocess.check_call(
-        [
-            "git",
-            "config",
-            "--global",
-            "--add",
-            "safe.directory",
-            str(config.dirs["images"]),
-        ],
-        cwd=config.dirs["images"],
-    )
+    # subprocess.check_call(
+    #     [
+    #         "git",
+    #         "config",
+    #         "--global",
+    #         "--add",
+    #         "safe.directory",
+    #         str(config.dirs["images"]),
+    #     ],
+    #     cwd=config.dirs["images"],
+    # )
     current_branch = subprocess.check_output(
         ["git", "branch", "--show-current"], encoding="utf8", cwd=config.dirs["images"]
     ).strip()
